#include "mainwindow.h"
#include "ui_mainwindow.h"

#include <QMessageBox>
#include <QMimeData>
#include <QStandardPaths>
#include <QDir>
#include <QProcess>
#include <QDateTime>
#include <QDebug>

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
    , ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    setAcceptDrops(true);

    connect(&xpdf, SIGNAL(finished(int,QProcess::ExitStatus)),
            SLOT(onProcessExit(int,QProcess::ExitStatus)));

    ui->lbMain->show();
    ui->pgMain->hide();
    ui->lbWait->hide();
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::dropEvent(QDropEvent *e)
{
    // pdftopng is get from xpdf-tools.
    QString process = qApp->applicationDirPath() + "/pdftopng.exe";
    QStringList parameters;
    QString desktop = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
    QString input = e->mimeData()->text(), input_name;

    // set DPI to 300 pixel/inch.
    parameters << "-r" << "300";

    // remove file:///, get the drop file path.
    parameters << input.remove(0, 8);
    input_name = input.mid(input.lastIndexOf("/")).remove(".pdf");

    // output to desktop, folder pdf2png.
    desktop = desktop + "/pdf2png/";
    QDir().mkdir(desktop);
    parameters << desktop + input_name;

    if (!QFile(process).exists()) {
        QMessageBox::critical(this, tr("Error"), tr("missing component."));
        return;
    }

    // now start convert process.
    xpdf.start(process, parameters);

    ui->lbMain->hide();
    ui->pgMain->show();
    ui->lbWait->show();
}

void MainWindow::dragEnterEvent(QDragEnterEvent *e)
{
    if (e->mimeData()->hasUrls()) {
        e->accept();
    }
}

void MainWindow::onProcessExit(int code, QProcess::ExitStatus status)
{
    if (status != QProcess::NormalExit) {
        QMessageBox::critical(this, tr("Error"), tr("execute error, code = %1!").arg(code));
        return;
    }

    ui->lbMain->show();
    ui->lbWait->hide();
    ui->pgMain->hide();
    QMessageBox::information(this, tr("Success"), tr("files saved to desktop folder pdf2png."));
}
